==> webpdf-wsclient-10.0.1-sources.jar: net/webpdf/wsclient/schema/operation/NonFullScreenPageModeType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p490833_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p603985_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:p985611_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Konfiguriert die Anzeige des Dokuments, wenn das Dokument nicht im Vollbildmodus betrachtet wird. Dies konfiguriert in erste Linie welche Navigationsansicht für den Betrachter geöffnet werden soll.&#13;
 *                     &lt;ul&gt;&lt;li&gt;none = Weder die Inhaltsübersicht, noch die Miniaturansicht der Seiten sollen angezeigt werden.&lt;/li&gt;&lt;li&gt;outlines = Die Inhaltsübersicht des Dokuments soll angezeigt werden.&lt;/li&gt;&lt;li&gt;thumbnails = Die Miniaturansicht der Seiten des Dokuments soll angezeigt werden.&lt;/li&gt;&lt;li&gt;optionalContents = Die Layer (Optional Content Groups) des Dokuments sollen angezeigt werden.&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for NonFullScreenPageModeType</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * <pre>{@code
 * <simpleType name="NonFullScreenPageModeType">
 *   <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     <enumeration value="none"/>
 *     <enumeration value="outlines"/>
 *     <enumeration value="thumbnails"/>
 *     <enumeration value="optionalContents"/>
 *   </restriction>
 * </simpleType>
 * }</pre>
 * 
 */
@XmlType(name = "NonFullScreenPageModeType")
@XmlEnum
public enum NonFullScreenPageModeType {

    @XmlEnumValue("none")
    NONE("none"),
    @XmlEnumValue("outlines")
    OUTLINES("outlines"),
    @XmlEnumValue("thumbnails")
    THUMBNAILS("thumbnails"),
    @XmlEnumValue("optionalContents")
    OPTIONAL_CONTENTS("optionalContents");
    private final String value;

    NonFullScreenPageModeType(String v) {
        value = v;
    }

    /**
     * Gets the value associated to the enum constant.
     * 
     * @return
     *     The value linked to the enum.
     */
    public String value() {
        return value;
    }

    /**
     * Gets the enum associated to the value passed as parameter.
     * 
     * @param v
     *     The value to get the enum from.
     * @return
     *     The enum which corresponds to the value, if it exists.
     * @throws IllegalArgumentException
     *     If no value matches in the enum declaration.
     */
    public static NonFullScreenPageModeType fromValue(String v) {
        for (NonFullScreenPageModeType c: NonFullScreenPageModeType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> webpdf-wsclient-10.0.2-sources.jar: net/webpdf/wsclient/schema/operation/NonFullScreenPageModeType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p356330_="https://jakarta.ee/xml/ns/jaxb" xmlns:p467749_="urn:jaxb.jvnet.org:plugin:simplify" xmlns:p726494_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Konfiguriert die Anzeige des Dokuments, wenn das Dokument nicht im Vollbildmodus betrachtet wird. Dies konfiguriert in erste Linie welche Navigationsansicht für den Betrachter geöffnet werden soll.&#13;
 *                     &lt;ul&gt;&lt;li&gt;none = Weder die Inhaltsübersicht, noch die Miniaturansicht der Seiten sollen angezeigt werden.&lt;/li&gt;&lt;li&gt;outlines = Die Inhaltsübersicht des Dokuments soll angezeigt werden.&lt;/li&gt;&lt;li&gt;thumbnails = Die Miniaturansicht der Seiten des Dokuments soll angezeigt werden.&lt;/li&gt;&lt;li&gt;optionalContents = Die Layer (Optional Content Groups) des Dokuments sollen angezeigt werden.&lt;/li&gt;&lt;/ul&gt;&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for NonFullScreenPageModeType</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * <pre>{@code
 * <simpleType name="NonFullScreenPageModeType">
 *   <restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     <enumeration value="none"/>
 *     <enumeration value="outlines"/>
 *     <enumeration value="thumbnails"/>
 *     <enumeration value="optionalContents"/>
 *   </restriction>
 * </simpleType>
 * }</pre>
 * 
 */
@XmlType(name = "NonFullScreenPageModeType")
@XmlEnum
public enum NonFullScreenPageModeType {

    @XmlEnumValue("none")
    NONE("none"),
    @XmlEnumValue("outlines")
    OUTLINES("outlines"),
    @XmlEnumValue("thumbnails")
    THUMBNAILS("thumbnails"),
    @XmlEnumValue("optionalContents")
    OPTIONAL_CONTENTS("optionalContents");
    private final String value;

    NonFullScreenPageModeType(String v) {
        value = v;
    }

    /**
     * Gets the value associated to the enum constant.
     * 
     * @return
     *     The value linked to the enum.
     */
    public String value() {
        return value;
    }

    /**
     * Gets the enum associated to the value passed as parameter.
     * 
     * @param v
     *     The value to get the enum from.
     * @return
     *     The enum which corresponds to the value, if it exists.
     * @throws IllegalArgumentException
     *     If no value matches in the enum declaration.
     */
    public static NonFullScreenPageModeType fromValue(String v) {
        for (NonFullScreenPageModeType c: NonFullScreenPageModeType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
